.. _todo:

TODO
####

Er moet aangifte tegen de staat gedaan worden voor het op grote schaal overtreden van de eigen wet, namelijk het misdrijf tegen het leven gericht.

Tweede kamer voor de stemming over de Wet verplichte GGZ nog een van het plegen van misdrijven in het kader van die wet benadrukken.

Advocaten email lijst opvragen bij voorzitter van advocatenverenigingen, om zodoende advies te kunnen vragen of er een "class action" achtige aangifte gedaan kan worden ofzo, is stap 1.

Dat het Openbaar Ministerie niet vervolgt voor het toedienen van antipsychotica maakt dat er elke dag zon 200.000 mensen gif krijgen toegediend.
Er moet pressie komen om het Openbaar Ministerie WEL te laten vervolgen voor het toedienen van antipsychotica.
De kosten van het nalaten van vervolging voor wat nu al strafbaar is moeten inzichtelijk worden.
